Single

Struct Single 

pub struct Single<'a, Q>(pub <Q as Query>::Item<'a>)
where
    Q: Query;
A HandlerParam which fetches a single entity from the world.

If there isn’t exactly one entity that matches the Query, a runtime panic occurs. This is useful for representing global variables or singleton entities.

Examples

use evenio::prelude::*;

#[derive(Component)]
struct MyComponent(i32);

let mut world = World::new();

world.add_handler(
    |_: Receiver<E>, Single(MyComponent(data)): Single<&MyComponent>| {
        println!("The data is: {data}");
    },
);

let e = world.spawn();
world.insert(e, MyComponent(123));

world.send(E);

Tuple Fields

0: <Q as Query>::Item<'a>