pub struct TargetedEventId(/* private fields */);Expand description
Lightweight identifier for a targeted event type.
Event identifiers are implemented using an index and a generation count. The generation count ensures that IDs from despawned events are not reused by new events.
An event identifier is only meaningful in the World it was created
from. Attempting to use an event ID in a different world will have
unexpected results.
Implementations
Sourceimpl TargetedEventId
impl TargetedEventId
Sourcepub const NULL: TargetedEventId
pub const NULL: TargetedEventId
The global event ID which never identifies a live entity. This is the
default value for EntityId.
Sourcepub const fn new(index: u32, generation: u32) -> Option<TargetedEventId>
pub const fn new(index: u32, generation: u32) -> Option<TargetedEventId>
Creates a new entity ID from an index and generation count. Returns
None if a valid ID is not formed.
Sourcepub const fn index(self) -> TargetedEventIdx
pub const fn index(self) -> TargetedEventIdx
Returns the index of this ID.
Sourcepub const fn generation(self) -> u32
pub const fn generation(self) -> u32
Returns the generation count of this ID.