pub struct ReceiverMut<'a, E, Q = NullReceiverQuery>where
E: Event,
Q: ReceiverQuery + 'static,{
pub event: EventMut<'a, E>,
pub query: <Q as ReceiverQuery>::Item<'a>,
}Expand description
Like Receiver, but provides mutable access to the received event. Prefer
Receiver if mutable access is not needed.
For more information, see the relevant tutorial chapter.
Fields
event: EventMut<'a, E>A mutable reference to the received event.
query: <Q as ReceiverQuery>::Item<'a>The result of the query. This field is meaningless if E is not a
targeted event.