pub struct Single<'a, Q>(pub <Q as Query>::Item<'a>)
where
Q: Query;Expand description
A HandlerParam which fetches a single entity from the world.
If there isn’t exactly one entity that matches the Query, a runtime
panic occurs. This is useful for representing global variables or singleton
entities.
Examples
use evenio::prelude::*;
#[derive(Component)]
struct MyComponent(i32);
let mut world = World::new();
world.add_handler(
|_: Receiver<E>, Single(MyComponent(data)): Single<&MyComponent>| {
println!("The data is: {data}");
},
);
let e = world.spawn();
world.insert(e, MyComponent(123));
world.send(E);Tuple Fields
0: <Q as Query>::Item<'a>Trait Implementations
Sourceimpl<Q> HandlerParam for Single<'_, Q>where
Q: Query + 'static,
impl<Q> HandlerParam for Single<'_, Q>where
Q: Query + 'static,
Sourcetype This<'a> = Single<'a, Q>
type This<'a> = Single<'a, Q>
The type produced by this handler param. This must be the type
of
Self but with the lifetime of 'a.Sourcefn init(
world: &mut World,
config: &mut HandlerConfig,
) -> Result<<Single<'_, Q> as HandlerParam>::State, InitError>
fn init( world: &mut World, config: &mut HandlerConfig, ) -> Result<<Single<'_, Q> as HandlerParam>::State, InitError>
Sourceunsafe fn get<'a>(
state: &'a mut <Single<'_, Q> as HandlerParam>::State,
info: &'a HandlerInfo,
event_ptr: EventPtr<'a>,
target_location: EntityLocation,
world: UnsafeWorldCell<'a>,
) -> <Single<'_, Q> as HandlerParam>::This<'a>
unsafe fn get<'a>( state: &'a mut <Single<'_, Q> as HandlerParam>::State, info: &'a HandlerInfo, event_ptr: EventPtr<'a>, target_location: EntityLocation, world: UnsafeWorldCell<'a>, ) -> <Single<'_, Q> as HandlerParam>::This<'a>
Obtains a new instance of the handler parameter. Read more
Sourcefn refresh_archetype(
state: &mut <Single<'_, Q> as HandlerParam>::State,
arch: &Archetype,
)
fn refresh_archetype( state: &mut <Single<'_, Q> as HandlerParam>::State, arch: &Archetype, )
Refresh an archetype for this handler param. Called whenever
Handler::refresh_archetype is called.Sourcefn remove_archetype(
state: &mut <Single<'_, Q> as HandlerParam>::State,
arch: &Archetype,
)
fn remove_archetype( state: &mut <Single<'_, Q> as HandlerParam>::State, arch: &Archetype, )
Remove the given archetype for this handler param. Called whenever
Handler::remove_archetype is called.Sourceimpl<'a, Q> Ord for Single<'a, Q>
impl<'a, Q> Ord for Single<'a, Q>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a, Q> PartialOrd for Single<'a, Q>
impl<'a, Q> PartialOrd for Single<'a, Q>
impl<'a, Q> Copy for Single<'a, Q>
impl<'a, Q> Eq for Single<'a, Q>
impl<'a, Q> StructuralPartialEq for Single<'a, Q>where
Q: Query,